<?php
/**
 * @brief		advancedwelcomeheader Widget
 * @author		<a href='https://www.invisioncommunity.com'>Invision Power Services, Inc.</a>
 * @copyright	(c) Invision Power Services, Inc.
 * @license		https://www.invisioncommunity.com/legal/standards/
 * @package		Invision Community
 * @subpackage	advancedwelcomeheader
 * @since		01 Sep 2023
 */

namespace IPS\advancedwelcomeheader\widgets;

/* To prevent PHP errors (extending class does not exist) revealing path */
if ( !\defined( '\IPS\SUITE_UNIQUE_KEY' ) )
{
	header( ( isset( $_SERVER['SERVER_PROTOCOL'] ) ? $_SERVER['SERVER_PROTOCOL'] : 'HTTP/1.0' ) . ' 403 Forbidden' );
	exit;
}

/**
 * advancedwelcomeheader Widget
 */
class _advancedwelcomeheader extends \IPS\Widget
{
	/**
	 * @brief	Widget Key
	 */
	public $key = 'advancedwelcomeheader';
	
	/**
	 * @brief	App
	 */
	public $app = 'advancedwelcomeheader';
		
	/**
	 * @brief	Plugin
	 */
	public $plugin = '';
	
	/**
	 * Initialise this widget
	 *
	 * @return void
	 */ 
	public function init()
	{
		// Use this to perform any set up and to assign a template that is not in the following format:
		// $this->template( array( \IPS\Theme::i()->getTemplate( 'widgets', $this->app, 'front' ), $this->key ) );
		// If you are creating a plugin, uncomment this line:
		$this->template( array( \IPS\Theme::i()->getTemplate( 'widgets', 'advancedwelcomeheader', 'front' ), $this->key ) );
		// And then create your template at located at plugins/<your plugin>/dev/html/advancedwelcomeheader.phtml
		
		
		parent::init();
	}
	
	/**
	 * Specify widget configuration
	 *
	 * @param	null|\IPS\Helpers\Form	$form	Form object
	 * @return	null|\IPS\Helpers\Form
	 */
	public function configuration( &$form=null )
	{
 		$form = parent::configuration( $form );

 		// $form->add( new \IPS\Helpers\Form\XXXX( .... ) );
 		return $form;
 	} 
 	
 	 /**
 	 * Ran before saving widget configuration
 	 *
 	 * @param	array	$values	Values from form
 	 * @return	array
 	 */
 	public function preConfig( $values )
 	{
 		return $values;
 	}

	/**
	 * Render a widget
	 *
	 * @return	string
	 */
	public function render()
	{
		$advancedwelcomeheader = array();
		/* Forum Posts */
		$approxRows = \IPS\Db::i()->query( "SHOW TABLE STATUS LIKE '" . \IPS\Db::i()->prefix . "forums_posts';" )->fetch_assoc();
		if( (int) $approxRows['Rows'] >= 1000000 )
		{
			$advancedwelcomeheader['total_posts'] = \IPS\Db::i()->select( 'SUM(posts)', 'forums_forums' )->first();
		}
		else
		{
			$advancedwelcomeheader['total_posts'] = \IPS\Db::i()->select( "COUNT(*)", 'forums_posts', array( 'queued = ?', 0 ) )->first();
		}
		if ( (int) $approxRows['Rows'] <= 1000000 AND \IPS\Settings::i()->archive_on )
		{
			$advancedwelcomeheader['total_posts'] += \IPS\forums\Topic\ArchivedPost::db()->select( 'COUNT(*)', 'forums_archive_posts', array( 'archive_queued = ?', 0 ) )->first();
		}
		/* Forum Tpoics */
		$advancedwelcomeheader['total_topics']	= \IPS\Db::i()->select( "COUNT(*)", 'forums_topics', array( 'approved = ?', 1 ) )->first();

		/* Memberstuff */		
		$advancedwelcomeheader['member'] = \IPS\Member::loggedIn()->name;
		$advancedwelcomeheader['joined'] = \IPS\Member::loggedIn()->joined;
		$advancedwelcomeheader['ranktitle'] = \IPS\Member::loggedIn()->rank()->_title;
		$advancedwelcomeheader['memberid'] = \IPS\Member::loggedIn()->member_id;
		$advancedwelcomeheader['activity'] = \IPS\Member::loggedIn()->last_activity;
		$advancedwelcomeheader['groupid'] = \IPS\Member::loggedIn()->member_group_id;
		$advancedwelcomeheader['lastpost'] = \IPS\Member::loggedIn()->member_last_post;

		$member = \IPS\Member::loggedIn();

		/* That's all, folks */	
		return $this->output( $advancedwelcomeheader, $member );
	}
}